@@ -281,12 +281,13 @@ int main(int argc, char **argv) {
     reporter_options.inhibit_finish_suite_message = false;
 
     int test_count = 0;
-    if (!have_xml_option() && suite_name_option != NULL) {
+    if (!have_xml_option() && (suite_name_option != NULL)) {
 
         /* Count all tests */
         for (i = 0; i<library_count; i++) {
             if (!file_exists(libraries[i])) {
                 printf("Couldn't find library: %s\n", libraries[i]);
+                any_fail = true;
                 break;
             }
 
@@ -303,10 +304,11 @@ int main(int argc, char **argv) {
 
         if (!file_exists(libraries[i])) {
             printf("Couldn't find library: %s\n", libraries[i]);
+            any_fail = true;
             break;
         }
 
-        if (!have_xml_option() && suite_name_option != NULL)
+        if (!have_xml_option() && (suite_name_option != NULL))
             inhibit_appropriate_suite_message(i, library_count);
 
         fail = run_tests_in_library(suite_name_option, testname[i], libraries[i],
